#
# spec file for package python-zope.interface
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-zope.interface
Version:        4.1.2
Release:        3.21
Url:            http://pypi.python.org/pypi/zope.interface
Summary:        Interfaces for Python
License:        ZPL-2.1
Group:          Development/Languages/Python
Source:         https://pypi.python.org/packages/source/z/zope.interface/zope.interface-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  fdupes
BuildRequires:  python-devel
BuildRequires:  python-setuptools
# Documentation requirements:
BuildRequires:  python-Sphinx
#!BuildIgnore:  python-zope.interface
BuildRequires:  python-repoze.sphinx.autointerface
# Testing requirements:
BuildRequires:  python-coverage
BuildRequires:  python-nose
BuildRequires:  python-zope.event
Provides:       python-zopeinterface = %{version}
Obsoletes:      python-zopeinterface < %{version}
Provides:       python-zope-interface = %{version}
Obsoletes:      python-zope-interface < %{version}

%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitearch: %global python_sitearch %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}
%endif

%description
This package is intended to be independently reusable in any Python
project. It is maintained by the Zope Toolkit project.

This package provides an implementation of object interfaces for Python.
Interfaces are a mechanism for labeling objects as conforming to a given
API or contract. So, this package can be considered as implementation of
the Design By Contract methodology support in Python.

%package doc
Summary:        Interfaces for Python
Group:          Development/Languages/Python
Requires:       %{name} = %{version}

%description doc
This package contains documentation files for %{name}.

%prep
%setup -q -n zope.interface-%{version}

%build
python setup.py build
PYTHONPATH=$(echo $(pwd)/build/lib.*) python setup.py build_sphinx && rm build/sphinx/html/.buildinfo

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
# Remove duplicate files
%fdupes -s %{buildroot}
rm %{buildroot}%python_sitearch/zope/interface/_zope_interface_coptimizations.c

%check
python setup.py -q test

%files
%defattr(-,root,root,-)
%doc COPYRIGHT.txt CHANGES.rst LICENSE.txt README.rst
%{python_sitearch}/*

%files doc
%defattr(-,root,root,-)
%doc build/sphinx/html/

%changelog
* Fri May 15 2015 benoit.monin@gmx.fr
- update to version 4.1.2:
  * Add support for PyPy3.
  * Remove unittest assertions deprecated in Python3.x.
  * Add zope.interface.document.asReStructuredText, which formats
    the generated text for an interface using ReST double-backtick
    markers.
- fix documentation generation
- pass -q to test to avoid spamming the build log
* Tue Sep 16 2014 tbechtold@suse.com
- Update to version 4.1.1:
  * Added support for Python 3.4.
* Sun Feb 16 2014 os-dev@jacraig.com
- Update to 4.1.0:
  * Updated ``boostrap.py`` to version 2.2.
  * Added ``@named(name)`` declaration, that specifies the component name, so
    it does not have to be passed in during registration.
- Change source URL, .zip not available for this version.
* Thu Dec 19 2013 coolo@suse.com
- BuildIgnore our own name - required by python-repoze.sphinx.autointerface,
  but of course not needed
* Thu Aug  1 2013 hpj@urpla.net
- add unzip to BuildRequires
* Thu Aug  1 2013 speilicke@suse.com
- Ship upstream tarbal (zipfile) and fix Source URL
* Mon Jul 29 2013 hpj@urpla.net
- Updated to 4.0.5:
  * Fixed a bug where a decorated method caused false positive failures on verifyClass().
- Updated to 4.0.4:
  * Fixed a bug that was revealed by porting zope.traversing. During a loop, the loop body modified a weakref dict causing a RuntimeError error.
- generate documentation in -doc package
- enable tests
* Mon Jan 14 2013 p.drouand@gmail.com
- Initial python3 support
* Mon Jan 14 2013 p.drouand@gmail.com
- Update to 4.0.3 version:
  * Fleshed out PyPI Trove classifiers.
- Remove duplicate files with fdupes
* Sun Oct 14 2012 douglarek@outlook.com
- Fix spec bugs
- Updated to 4.0.1
  * Dropped explicit DeprecationWarnings for "class advice" APIS (these APIs are still deprecated under Python 2.x, and still raise an exception under Python 3.x, but no longer cause a warning to be emitted under Python 2.x).
  * Automated build of Sphinx HTML docs and running doctest snippets via tox.
  * Deprecated the "class advice" APIs from zope.interface.declarations: implements, implementsOnly, and classProvides. In their place, prefer the equivalent class decorators: @implementer, @implementer_only, and @provider. Code which uses the deprecated APIs will not work as expected under Py3k.
  * Removed use of '2to3' and associated fixers when installing under Py3k. The code is now in a "compatible subset" which supports Python 2.6, 2.7, and 3.2, including PyPy 1.8 (the version compatible with the 2.7 language spec).
  * Dropped explicit support for Python 2.4 / 2.5 / 3.1.
  * Added support for PyPy.
  * Added support for continuous integration using tox and jenkins.
  * Added 'setup.py dev' alias (runs setup.py develop plus installs nose and coverage).
  * Added 'setup.py docs' alias (installs Sphinx and dependencies).
  * Replaced all unittest coverage previously accomplished via doctests with unittests. The doctests have been moved into a docs section, managed as a Sphinx collection.
  * LP #910987: Ensure that the semantics of the lookup method of zope.interface.adapter.LookupBase are the same in both the C and Python implementations.
  * LP #900906: Avoid exceptions due to tne new __qualname__ attribute added in Python 3.3 (see PEP 3155 for rationale). Thanks to Antoine Pitrou for the patch.
* Wed Feb  1 2012 saschpe@suse.de
- Simplified macro usage
* Fri Sep 23 2011 saschpe@suse.de
- Update to version 3.8.0:
  * New module zope.interface.registry
  * No longer Python 2.4 compatible (tested under 2.5, 2.6, 2.7, and 3.2).
* Tue Sep  6 2011 saschpe@suse.de
- Added provides/obsoletes for python-zope-interface
* Tue Sep  6 2011 saschpe@suse.de
- Renamed to python-zope.interface (from python-zopeinterface)
- Simplyfied spec file
- Update to version 3.7.0:
  * LP #570942: Now correctly compare interfaces from different modules
    but with the same names.
  * LP #811792:  work around buggy behavior in some subclasses of
    zope.interface.interface.InterfaceClass, which invoke __hash__
    before initializing __module__ and __name__.  The workaround
    returns a fixed constant hash in such cases, and issues a UserWarning.
  * LP #804832: Under PyPy, zope.interface should not build its C
    extension. Also, prevent attempting to build it under Jython.
  * Add a tox.ini for easier xplatform testing.
  * Fix testing deprecation warnings issued when tested under Py3K.
  * LP 804951: InterfaceClass instances were unhashable under Python 3.x.
  * LP #570942: Now correctly compare interfaces  from different modules
    but with the same names.
* Wed Dec 15 2010 saschpe@suse.de
- add documentation files: COPYRIGHT.txt CHANGES.txt LICENSE.txt
* Sun Dec 12 2010 saschpe@gmx.de
- update to 3.6.1
  * A non-ascii character in the changelog made 3.6.0 uninstallable
    on Python 3 systems with another default encoding than UTF-8.
  * Fixed compiler warnings under GCC 4.3.3.
  * Python 2.3 is no longer supported.
  * Use the standard Python doctest module instead of
    zope.testing.doctest, which has been deprecated.
  * Allow to bootstrap on Jython.
- re-packaged with py2pack
  * now builds on all RPM-based distros
* Tue Jun  3 2008 crrodriguez@suse.de
- needs fno-strict-aliasing
* Thu Aug  2 2007 jmatejek@suse.cz
- update to 3.3.0
  * corresponds to new Zope versions
  * adapter-lookup written in C to simplify application debugging
  * various bugfixes
* Thu Oct 19 2006 jmatejek@suse.cz
- minor changes for better 64bit compatibility with PEP353
* Tue Feb 28 2006 jmatejek@suse.cz
- updated to reflect python changes due to #149809
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Apr 14 2005 mcihar@suse.cz
- new package
